/**
 * Plugin to transform markdown to React.
 *
 * @type {import('unified').Plugin<[Options], Root, ReactElement>}
 */
export default function remarkReact(options: Options): void
export type Root = import('mdast').Root
export type Schema = import('hast-util-sanitize').Schema
export type ToHastOptions = import('mdast-util-to-hast').Options
export type ReactNode = import('react').ReactNode
export type ReactElement = import('react').ReactElement<unknown>
export type CreateElementLike = (
  name: any,
  props: any,
  ...children: ReactNode[]
) => ReactNode
export type Options = {
  /**
   * How to create elements or components.
   * You should typically pass `React.createElement`.
   */
  createElement: CreateElementLike
  /**
   * Create fragments instead of an outer `<div>` if available.
   * You should typically pass `React.Fragment`.
   */
  Fragment?: ((props: any) => ReactNode) | undefined
  /**
   * React key prefix
   */
  prefix?: string | undefined
  /**
   * Options for `hast-util-sanitize`.
   */
  sanitize?: boolean | import('hast-util-sanitize/lib').Schema | undefined
  /**
   * Options for `mdast-util-to-hast`.
   */
  toHast?: import('mdast-util-to-hast/lib').Options | undefined
  /**
   * Override default elements (such as `<a>`, `<p>`, etcetera) by passing an
   * object mapping tag names to components.
   */
  remarkReactComponents?:
    | Partial<{
        a:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').AnchorHTMLAttributes<HTMLAnchorElement>,
                HTMLAnchorElement
              >
            ) => ReactNode)
        abbr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        address:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        area:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').AreaHTMLAttributes<HTMLAreaElement>,
                HTMLAreaElement
              >
            ) => ReactNode)
        article:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        aside:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        audio:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').AudioHTMLAttributes<HTMLAudioElement>,
                HTMLAudioElement
              >
            ) => ReactNode)
        b:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        base:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').BaseHTMLAttributes<HTMLBaseElement>,
                HTMLBaseElement
              >
            ) => ReactNode)
        bdi:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        bdo:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        big:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        blockquote:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').BlockquoteHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        body:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLBodyElement>,
                HTMLBodyElement
              >
            ) => ReactNode)
        br:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLBRElement>,
                HTMLBRElement
              >
            ) => ReactNode)
        button:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ButtonHTMLAttributes<HTMLButtonElement>,
                HTMLButtonElement
              >
            ) => ReactNode)
        canvas:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').CanvasHTMLAttributes<HTMLCanvasElement>,
                HTMLCanvasElement
              >
            ) => ReactNode)
        caption:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        cite:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        code:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        col:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ColHTMLAttributes<HTMLTableColElement>,
                HTMLTableColElement
              >
            ) => ReactNode)
        colgroup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ColgroupHTMLAttributes<HTMLTableColElement>,
                HTMLTableColElement
              >
            ) => ReactNode)
        data:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DataHTMLAttributes<HTMLDataElement>,
                HTMLDataElement
              >
            ) => ReactNode)
        datalist:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLDataListElement>,
                HTMLDataListElement
              >
            ) => ReactNode)
        dd:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        del:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DelHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        details:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DetailsHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        dfn:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        dialog:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').DialogHTMLAttributes<HTMLDialogElement>,
                HTMLDialogElement
              >
            ) => ReactNode)
        div:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLDivElement>,
                HTMLDivElement
              >
            ) => ReactNode)
        dl:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLDListElement>,
                HTMLDListElement
              >
            ) => ReactNode)
        dt:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        em:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        embed:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').EmbedHTMLAttributes<HTMLEmbedElement>,
                HTMLEmbedElement
              >
            ) => ReactNode)
        fieldset:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').FieldsetHTMLAttributes<HTMLFieldSetElement>,
                HTMLFieldSetElement
              >
            ) => ReactNode)
        figcaption:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        figure:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        footer:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        form:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').FormHTMLAttributes<HTMLFormElement>,
                HTMLFormElement
              >
            ) => ReactNode)
        h1:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h2:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h3:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h4:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h5:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        h6:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadingElement>,
                HTMLHeadingElement
              >
            ) => ReactNode)
        head:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHeadElement>,
                HTMLHeadElement
              >
            ) => ReactNode)
        header:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        hgroup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        hr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLHRElement>,
                HTMLHRElement
              >
            ) => ReactNode)
        html:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HtmlHTMLAttributes<HTMLHtmlElement>,
                HTMLHtmlElement
              >
            ) => ReactNode)
        i:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        iframe:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').IframeHTMLAttributes<HTMLIFrameElement>,
                HTMLIFrameElement
              >
            ) => ReactNode)
        img:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ImgHTMLAttributes<HTMLImageElement>,
                HTMLImageElement
              >
            ) => ReactNode)
        input:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').InputHTMLAttributes<HTMLInputElement>,
                HTMLInputElement
              >
            ) => ReactNode)
        ins:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').InsHTMLAttributes<HTMLModElement>,
                HTMLModElement
              >
            ) => ReactNode)
        kbd:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        keygen:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').KeygenHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        label:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').LabelHTMLAttributes<HTMLLabelElement>,
                HTMLLabelElement
              >
            ) => ReactNode)
        legend:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLLegendElement>,
                HTMLLegendElement
              >
            ) => ReactNode)
        li:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').LiHTMLAttributes<HTMLLIElement>,
                HTMLLIElement
              >
            ) => ReactNode)
        link:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').LinkHTMLAttributes<HTMLLinkElement>,
                HTMLLinkElement
              >
            ) => ReactNode)
        main:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        map:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MapHTMLAttributes<HTMLMapElement>,
                HTMLMapElement
              >
            ) => ReactNode)
        mark:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        menu:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MenuHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        menuitem:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        meta:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MetaHTMLAttributes<HTMLMetaElement>,
                HTMLMetaElement
              >
            ) => ReactNode)
        meter:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').MeterHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        nav:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        noindex:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        noscript:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        object:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ObjectHTMLAttributes<HTMLObjectElement>,
                HTMLObjectElement
              >
            ) => ReactNode)
        ol:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OlHTMLAttributes<HTMLOListElement>,
                HTMLOListElement
              >
            ) => ReactNode)
        optgroup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OptgroupHTMLAttributes<HTMLOptGroupElement>,
                HTMLOptGroupElement
              >
            ) => ReactNode)
        option:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OptionHTMLAttributes<HTMLOptionElement>,
                HTMLOptionElement
              >
            ) => ReactNode)
        output:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').OutputHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        p:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLParagraphElement>,
                HTMLParagraphElement
              >
            ) => ReactNode)
        param:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ParamHTMLAttributes<HTMLParamElement>,
                HTMLParamElement
              >
            ) => ReactNode)
        picture:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        pre:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLPreElement>,
                HTMLPreElement
              >
            ) => ReactNode)
        progress:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ProgressHTMLAttributes<HTMLProgressElement>,
                HTMLProgressElement
              >
            ) => ReactNode)
        q:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').QuoteHTMLAttributes<HTMLQuoteElement>,
                HTMLQuoteElement
              >
            ) => ReactNode)
        rp:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        rt:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        ruby:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        s:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        samp:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        slot:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').SlotHTMLAttributes<HTMLSlotElement>,
                HTMLSlotElement
              >
            ) => ReactNode)
        script:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ScriptHTMLAttributes<HTMLScriptElement>,
                HTMLScriptElement
              >
            ) => ReactNode)
        section:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        select:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').SelectHTMLAttributes<HTMLSelectElement>,
                HTMLSelectElement
              >
            ) => ReactNode)
        small:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        source:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').SourceHTMLAttributes<HTMLSourceElement>,
                HTMLSourceElement
              >
            ) => ReactNode)
        span:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLSpanElement>,
                HTMLSpanElement
              >
            ) => ReactNode)
        strong:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        style:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').StyleHTMLAttributes<HTMLStyleElement>,
                HTMLStyleElement
              >
            ) => ReactNode)
        sub:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        summary:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        sup:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        table:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TableHTMLAttributes<HTMLTableElement>,
                HTMLTableElement
              >
            ) => ReactNode)
        template:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTemplateElement>,
                HTMLTemplateElement
              >
            ) => ReactNode)
        tbody:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableSectionElement>,
                HTMLTableSectionElement
              >
            ) => ReactNode)
        td:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TdHTMLAttributes<HTMLTableDataCellElement>,
                HTMLTableDataCellElement
              >
            ) => ReactNode)
        textarea:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TextareaHTMLAttributes<HTMLTextAreaElement>,
                HTMLTextAreaElement
              >
            ) => ReactNode)
        tfoot:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableSectionElement>,
                HTMLTableSectionElement
              >
            ) => ReactNode)
        th:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').ThHTMLAttributes<HTMLTableHeaderCellElement>,
                HTMLTableHeaderCellElement
              >
            ) => ReactNode)
        thead:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableSectionElement>,
                HTMLTableSectionElement
              >
            ) => ReactNode)
        time:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TimeHTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        title:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTitleElement>,
                HTMLTitleElement
              >
            ) => ReactNode)
        tr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLTableRowElement>,
                HTMLTableRowElement
              >
            ) => ReactNode)
        track:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').TrackHTMLAttributes<HTMLTrackElement>,
                HTMLTrackElement
              >
            ) => ReactNode)
        u:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        ul:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLUListElement>,
                HTMLUListElement
              >
            ) => ReactNode)
        var:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        video:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').VideoHTMLAttributes<HTMLVideoElement>,
                HTMLVideoElement
              >
            ) => ReactNode)
        wbr:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').HTMLAttributes<HTMLElement>,
                HTMLElement
              >
            ) => ReactNode)
        webview:
          | string
          | ((
              props: import('react').DetailedHTMLProps<
                import('react').WebViewHTMLAttributes<HTMLWebViewElement>,
                HTMLWebViewElement
              >
            ) => ReactNode)
        svg:
          | string
          | ((props: import('react').SVGProps<SVGSVGElement>) => ReactNode)
        animate:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        animateMotion:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        animateTransform:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        circle:
          | string
          | ((props: import('react').SVGProps<SVGCircleElement>) => ReactNode)
        clipPath:
          | string
          | ((props: import('react').SVGProps<SVGClipPathElement>) => ReactNode)
        defs:
          | string
          | ((props: import('react').SVGProps<SVGDefsElement>) => ReactNode)
        desc:
          | string
          | ((props: import('react').SVGProps<SVGDescElement>) => ReactNode)
        ellipse:
          | string
          | ((props: import('react').SVGProps<SVGEllipseElement>) => ReactNode)
        feBlend:
          | string
          | ((props: import('react').SVGProps<SVGFEBlendElement>) => ReactNode)
        feColorMatrix:
          | string
          | ((
              props: import('react').SVGProps<SVGFEColorMatrixElement>
            ) => ReactNode)
        feComponentTransfer:
          | string
          | ((
              props: import('react').SVGProps<SVGFEComponentTransferElement>
            ) => ReactNode)
        feComposite:
          | string
          | ((
              props: import('react').SVGProps<SVGFECompositeElement>
            ) => ReactNode)
        feConvolveMatrix:
          | string
          | ((
              props: import('react').SVGProps<SVGFEConvolveMatrixElement>
            ) => ReactNode)
        feDiffuseLighting:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDiffuseLightingElement>
            ) => ReactNode)
        feDisplacementMap:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDisplacementMapElement>
            ) => ReactNode)
        feDistantLight:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDistantLightElement>
            ) => ReactNode)
        feDropShadow:
          | string
          | ((
              props: import('react').SVGProps<SVGFEDropShadowElement>
            ) => ReactNode)
        feFlood:
          | string
          | ((props: import('react').SVGProps<SVGFEFloodElement>) => ReactNode)
        feFuncA:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncAElement>) => ReactNode)
        feFuncB:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncBElement>) => ReactNode)
        feFuncG:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncGElement>) => ReactNode)
        feFuncR:
          | string
          | ((props: import('react').SVGProps<SVGFEFuncRElement>) => ReactNode)
        feGaussianBlur:
          | string
          | ((
              props: import('react').SVGProps<SVGFEGaussianBlurElement>
            ) => ReactNode)
        feImage:
          | string
          | ((props: import('react').SVGProps<SVGFEImageElement>) => ReactNode)
        feMerge:
          | string
          | ((props: import('react').SVGProps<SVGFEMergeElement>) => ReactNode)
        feMergeNode:
          | string
          | ((
              props: import('react').SVGProps<SVGFEMergeNodeElement>
            ) => ReactNode)
        feMorphology:
          | string
          | ((
              props: import('react').SVGProps<SVGFEMorphologyElement>
            ) => ReactNode)
        feOffset:
          | string
          | ((props: import('react').SVGProps<SVGFEOffsetElement>) => ReactNode)
        fePointLight:
          | string
          | ((
              props: import('react').SVGProps<SVGFEPointLightElement>
            ) => ReactNode)
        feSpecularLighting:
          | string
          | ((
              props: import('react').SVGProps<SVGFESpecularLightingElement>
            ) => ReactNode)
        feSpotLight:
          | string
          | ((
              props: import('react').SVGProps<SVGFESpotLightElement>
            ) => ReactNode)
        feTile:
          | string
          | ((props: import('react').SVGProps<SVGFETileElement>) => ReactNode)
        feTurbulence:
          | string
          | ((
              props: import('react').SVGProps<SVGFETurbulenceElement>
            ) => ReactNode)
        filter:
          | string
          | ((props: import('react').SVGProps<SVGFilterElement>) => ReactNode)
        foreignObject:
          | string
          | ((
              props: import('react').SVGProps<SVGForeignObjectElement>
            ) => ReactNode)
        g:
          | string
          | ((props: import('react').SVGProps<SVGGElement>) => ReactNode)
        image:
          | string
          | ((props: import('react').SVGProps<SVGImageElement>) => ReactNode)
        line:
          | string
          | ((props: import('react').SVGProps<SVGLineElement>) => ReactNode)
        linearGradient:
          | string
          | ((
              props: import('react').SVGProps<SVGLinearGradientElement>
            ) => ReactNode)
        marker:
          | string
          | ((props: import('react').SVGProps<SVGMarkerElement>) => ReactNode)
        mask:
          | string
          | ((props: import('react').SVGProps<SVGMaskElement>) => ReactNode)
        metadata:
          | string
          | ((props: import('react').SVGProps<SVGMetadataElement>) => ReactNode)
        mpath:
          | string
          | ((props: import('react').SVGProps<SVGElement>) => ReactNode)
        path:
          | string
          | ((props: import('react').SVGProps<SVGPathElement>) => ReactNode)
        pattern:
          | string
          | ((props: import('react').SVGProps<SVGPatternElement>) => ReactNode)
        polygon:
          | string
          | ((props: import('react').SVGProps<SVGPolygonElement>) => ReactNode)
        polyline:
          | string
          | ((props: import('react').SVGProps<SVGPolylineElement>) => ReactNode)
        radialGradient:
          | string
          | ((
              props: import('react').SVGProps<SVGRadialGradientElement>
            ) => ReactNode)
        rect:
          | string
          | ((props: import('react').SVGProps<SVGRectElement>) => ReactNode)
        stop:
          | string
          | ((props: import('react').SVGProps<SVGStopElement>) => ReactNode)
        switch:
          | string
          | ((props: import('react').SVGProps<SVGSwitchElement>) => ReactNode)
        symbol:
          | string
          | ((props: import('react').SVGProps<SVGSymbolElement>) => ReactNode)
        text:
          | string
          | ((props: import('react').SVGProps<SVGTextElement>) => ReactNode)
        textPath:
          | string
          | ((props: import('react').SVGProps<SVGTextPathElement>) => ReactNode)
        tspan:
          | string
          | ((props: import('react').SVGProps<SVGTSpanElement>) => ReactNode)
        use:
          | string
          | ((props: import('react').SVGProps<SVGUseElement>) => ReactNode)
        view:
          | string
          | ((props: import('react').SVGProps<SVGViewElement>) => ReactNode)
      }>
    | undefined
}
